@@ -298,7 +298,11 @@ QString DocumentPage::getFullText()
 	}
 	if (m_lineEnding == 1) { // Windows line ending mode
 		fullText.replace("\n", "\r\n");
-	}
+        fullText.replace("\r\r\n", "\r\n");
+    } else {
+        fullText.replace("\r\r\n", "\r\n");
+        fullText.replace("\r\n", "\n");
+    }
 	return fullText;
 }
 
@@ -1185,7 +1189,7 @@ void DocumentPage::init(QWidget *parent, OpEntryParser *opcodeTree)
 	saveLiveEvents = true;
 
 	m_view = new DocumentView(parent, opcodeTree);
-	connect(m_view, SIGNAL(evaluate(QString)), this, SLOT(evaluate(QString)));
+	//connect(m_view, SIGNAL(evaluate(QString)), this, SLOT(evaluate(QString)));
 	connect(m_view,SIGNAL(setHelp()), this, SLOT(setHelp()));
 	connect(m_view, SIGNAL(closeExtraPanels()), this, SLOT(closeExtraPanels()));
 
