@@ -142,6 +142,7 @@ public:
 	// Engine
 	CsoundEngine *getEngine(int index = -1);
 	OpEntryParser *m_opcodeTree;
+	void stkCheck();
 	// localServer
 	bool startServer();
 public slots:
@@ -231,6 +232,7 @@ private slots:
 	void openPdfFile(QString name);
 	void openFLOSSManual();
 	void openQuickRef();
+	void openOnlineDocumentation();
 	void resetPreferences();
 	void reportBug();
 	void requestFeature();
@@ -419,6 +421,7 @@ private:
 	QAction *browseForwardAct;
 	QAction *externalBrowserAct;
 	QAction *openQuickRefAct;
+	QAction *openDocumentationAct;
 	QAction *showUtilitiesAct;
 	QAction *showWidgetsAct;
 	QAction *showInspectorAct;
